==> tekton-model-triggers-v1alpha1-6.3.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerConfigFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EventListenerConfigFluentImpl<A extends EventListenerConfigFluent<A>> extends BaseFluent<A> implements EventListenerConfigFluent<A>{
  public EventListenerConfigFluentImpl() {
  }
  public EventListenerConfigFluentImpl(EventListenerConfig instance) {
    this.withGeneratedName(instance.getGeneratedName()); 
  }
  private String generatedName;
  public String getGeneratedName() {
    return this.generatedName;
  }
  public A withGeneratedName(String generatedName) {
    this.generatedName=generatedName; return (A) this;
  }
  public Boolean hasGeneratedName() {
    return this.generatedName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EventListenerConfigFluentImpl that = (EventListenerConfigFluentImpl) o;
    if (generatedName != null ? !generatedName.equals(that.generatedName) :that.generatedName != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(generatedName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (generatedName != null) { sb.append("generatedName:"); sb.append(generatedName); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerConfigFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EventListenerConfigFluentImpl<A extends EventListenerConfigFluent<A>> extends BaseFluent<A> implements EventListenerConfigFluent<A>{
  public EventListenerConfigFluentImpl() {
  }
  public EventListenerConfigFluentImpl(EventListenerConfig instance) {
    if (instance != null) {
      this.withGeneratedName(instance.getGeneratedName());
    }
  }
  private String generatedName;
  public String getGeneratedName() {
    return this.generatedName;
  }
  public A withGeneratedName(String generatedName) {
    this.generatedName=generatedName; return (A) this;
  }
  public Boolean hasGeneratedName() {
    return this.generatedName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EventListenerConfigFluentImpl that = (EventListenerConfigFluentImpl) o;
    if (!java.util.Objects.equals(generatedName, that.generatedName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(generatedName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (generatedName != null) { sb.append("generatedName:"); sb.append(generatedName); }
    sb.append("}");
    return sb.toString();
  }
  
}
